```bash
pip install mqp-client
```

## Usage

```python
from mqp_client import MQPClient

URL = "<mqp-api-url>"
TOKEN = "<your-mqp-token>"

# create a client instance
client = MQPClient(token=TOKEN, url=URL)
```
